using System;

namespace ExtendingTheGridView.Controls
{
    /// Copyright (c) 2008 Kerry D. Wong (http://www.kerrywong.com)
    /// Permission is hereby granted, free of charge, to any person
    /// obtaining a copy of this software and associated documentation
    /// files (the "Software"), to deal in the Software without
    /// restriction, including without limitation the rights to use,
    /// copy, modify, merge, publish, distribute, sublicense, and/or sell
    /// copies of the Software, and to permit persons to whom the
    /// Software is furnished to do so, subject to the following
    /// conditions:
    /// 
    /// The above copyright notice and this permission notice shall be
    /// included in all copies or substantial portions of the Software.
    ///
    /// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
    /// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
    /// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
    /// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
    /// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
    /// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
    /// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
    /// OTHER DEALINGS IN THE SOFTWARE.
    public partial class GridViewPager : System.Web.UI.UserControl
    {
        public delegate void SelectedIndexChangedHandler(object sender, int pageSize);
        public event SelectedIndexChangedHandler SelectedIndexChanged;

        private bool _visible = false;
        private int _pageSize = 10;

        public override bool Visible
        {
            get
            {
                if (ViewState[UniqueID] == null)
                    _visible = true;
                else
                    bool.TryParse(ViewState[this.UniqueID].ToString(), out _visible);

                return _visible;
            }
            set
            {
                _visible = value;
                ViewState[UniqueID] = _visible;

                if (_visible)
                    MainPanel.Visible = true;
                else
                    MainPanel.Visible = false;
            }
        }

        public int PageSize
        {
            get
            {
                if (ViewState[string.Concat(UniqueID, "PageSize")] == null)
                    _pageSize = int.Parse(DropDownItemsPerPage.SelectedValue);
                else
                    _pageSize = int.Parse(ViewState[string.Concat(UniqueID, "PageSize")].ToString());

                return _pageSize;
            }
            set
            {
                _pageSize = value;
                ViewState[String.Concat(UniqueID, "PageSize")] = value;
            }
        }

        protected override void OnInit(EventArgs e)
        {
            DropDownItemsPerPage.SelectedIndexChanged += new EventHandler(DropDownItemsPerPage_SelectedIndexChanged);
            base.OnInit(e);
        }

        protected void DropDownItemsPerPage_SelectedIndexChanged(object sender, EventArgs e)
        {
            PageSize = int.Parse(DropDownItemsPerPage.SelectedValue);

            if (SelectedIndexChanged != null)
                SelectedIndexChanged(sender, PageSize);
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
                DropDownItemsPerPage.DataBind();
        }

        /// <summary>
        /// This method links to the DataSourceChangedEvent defined in GridViewEx so that
        /// we can decide whether or not to show the pager depending on whether the list
        /// to be bound is empty.
        /// </summary>
        /// <param name="sender">sender object</param>
        /// <param name="isEmpty">whether the list to be bound is empty</param>
        public void GridViewDataSourceChanged(object sender, bool isEmpty)
        {
            if (isEmpty)
                Visible = false;
            else
                Visible = true;
        }
    }
}